
.. _config:

SDSSWORK
--------

This is the default configuration loaded.  It defines the current set of environment variables.

.. datamodel:: tree.tree:Tree
   :prog: sdsswork
   :title: sdsswork
   :remove-sasbase:

